"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transactionSchema = exports.transactionFields = void 0;
const yup_1 = require("yup");
const validUrlSchema_1 = require("./validUrlSchema");
const lib_1 = require("../../lib");
const helpers_1 = require("../../helpers");
const transactionFields = ({ isMainnet, hookWhitelist, isSignHook = false }) => {
    return {
        data: (0, yup_1.mixed)(),
        token: (0, yup_1.string)().when(['data'], (data, schema) => {
            return schema.test('notAllowed', 'Token and data not allowed', (value) => !Boolean(value && data));
        }),
        sender: (0, yup_1.string)(),
        gasLimit: (0, yup_1.string)().test('validInteger', 'Gas limit invaild', (value) => {
            if (value != null && value !== '') {
                return (0, lib_1.stringIsInteger)(value);
            }
            return true;
        }),
        gasPrice: (0, yup_1.string)().test('validFloat', 'Gas price invaild', (value) => {
            if (value != null && value !== '') {
                return (0, lib_1.stringIsInteger)(value);
            }
            return true;
        }),
        receiver: (0, yup_1.string)()
            .required()
            .test('allowed', 'Receiver address not allowed', function checkReceiver(value) {
            const data = this.parent.data;
            const decodedData = decodeURIComponent(data);
            if ((0, helpers_1.isNftOrMultiEsdtTx)(decodedData)) {
                return true;
            }
            const whitelist = hookWhitelist ?? [];
            const isNotSignHookOnMainnet = isMainnet && !isSignHook;
            return (!isNotSignHookOnMainnet ||
                whitelist.includes(String(value)) ||
                (0, lib_1.isContract)(String(value)));
        }),
        value: (0, yup_1.string)()
            .test('required', 'Value field required', function checkReceiver(value) {
            const data = this.parent.data;
            const decodedData = decodeURIComponent(data);
            if ((0, helpers_1.isNftOrMultiEsdtTx)(decodedData)) {
                return true;
            }
            return value != null;
        })
            .test('validInteger', 'Value invaild number', (value) => {
            if (value != null) {
                return (0, lib_1.stringIsInteger)(value);
            }
            return true;
        })
    };
};
exports.transactionFields = transactionFields;
const transactionSchema = ({ isMainnet }) => {
    const txFields = (0, exports.transactionFields)({ isMainnet });
    return (0, yup_1.object)({
        ...txFields,
        callbackUrl: validUrlSchema_1.validUrlSchema.required()
    }).required();
};
exports.transactionSchema = transactionSchema;
//# sourceMappingURL=transaction.js.map