"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSignMessageHookData = void 0;
const helpers_1 = require("../../helpers");
const sanitizeSignHookCallbackUrl_1 = require("../../hooks/helpers/sanitizeSignHookCallbackUrl/sanitizeSignHookCallbackUrl");
const signMessage_1 = require("../../hooks/helpers/signMessage");
const IS_DEVELOPMENT = process.env.NODE_ENV === 'development' ||
    window.location.hostname === 'localhost';
const getSignMessageHookData = (search = window.location.search) => {
    const hook = (0, helpers_1.parseQueryParams)(search);
    let isValid = false;
    try {
        signMessage_1.signMessageSchema.validateSync(hook, { strict: true });
        isValid = true;
    }
    catch ({ path, message }) {
        if (IS_DEVELOPMENT) {
            console.error('hook format errors: ', {
                [String(path)]: message
            });
        }
    }
    if (!isValid) {
        return null;
    }
    const { callbackUrl } = (0, sanitizeSignHookCallbackUrl_1.sanitizeSignHookCallbackUrl)({
        callbackUrl: hook.callbackUrl
    });
    return {
        hookUrl: search,
        callbackUrl
    };
};
exports.getSignMessageHookData = getSignMessageHookData;
//# sourceMappingURL=getSignMessageHookData.js.map