"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const replyUrl_1 = require("../replyUrl");
describe('replyToDapp tests', () => {
    const url = 'https://wallet.multiversx.com';
    test('returns callbackUrl unmodified if urlParams is empty', () => {
        expect((0, replyUrl_1.replyUrl)({ callbackUrl: url })).toBe('https://wallet.multiversx.com/');
    });
    test('adds urlParams', () => {
        expect((0, replyUrl_1.replyUrl)({
            callbackUrl: url,
            urlParams: { status: 'success' }
        })).toBe('https://wallet.multiversx.com/?status=success');
    });
    test('adds urlParams and keeps existing hash', () => {
        expect((0, replyUrl_1.replyUrl)({
            callbackUrl: url + '#test',
            urlParams: { status: 'success' }
        })).toBe('https://wallet.multiversx.com/?status=success#test');
    });
    test('keeps existing urlParams', () => {
        expect((0, replyUrl_1.replyUrl)({
            callbackUrl: url + '?page=1',
            urlParams: { status: 'success' }
        })).toBe('https://wallet.multiversx.com/?page=1&status=success');
    });
    test('keeps existing hash', () => {
        expect((0, replyUrl_1.replyUrl)({
            callbackUrl: url + '?page=1#logs',
            urlParams: { status: 'success' }
        })).toBe('https://wallet.multiversx.com/?page=1&status=success#logs');
    });
    test('throws error if callbackUrl is invalid and urlParams are defined', () => {
        expect((0, replyUrl_1.replyUrl)({
            callbackUrl: '',
            urlParams: { status: 'success' }
        })).toBe('');
    });
});
//# sourceMappingURL=replyUrl.spec.js.map